==> node-ace-code_1.35.4+~cs1.7.37.orig.tar.xz: ace-1.35.4/src/theme/cloud_editor-css.js <==
module.exports = `
.ace-cloud_editor .ace_gutter {
    background: #ffffff;
    color: #3a3a42;
}

.ace-cloud_editor .ace_tooltip-marker-error.ace_tooltip-marker {
    background-color: #d13212;
}
.ace-cloud_editor .ace_tooltip-marker-warning.ace_tooltip-marker {
    background-color: #906806;
}

.ace-cloud_editor .ace_print-margin {
    width: 1px;
    background: #697077;
}

.ace-cloud_editor {
    background-color: #ffffff;
    color: #3a3a42;
}

.ace-cloud_editor .ace_cursor {
    color: #3a3a42;
}

.ace-cloud_editor .ace_marker-layer .ace_selection {
    background: #bfceff;
}

.ace-cloud_editor.ace_multiselect .ace_selection.ace_start {
    box-shadow: 0 0 3px 0px #ffffff;
    border-radius: 2px;
}

.ace-cloud_editor .ace_marker-layer .ace_step {
    background: #697077;
}

.ace-cloud_editor .ace_marker-layer .ace_bracket {
    margin: 0 0 0 -1px;
    border: 1px solid #697077;
}

.ace-cloud_editor .ace_marker-layer .ace_active-line {
    box-sizing: border-box;
    border-top: 1px solid #9191ac;
    border-bottom: 1px solid #9191ac;
}

.ace-cloud_editor .ace_gutter-cell_svg-icons {
    box-sizing: border-box;
    border-top: 1px solid #ffffff;
    border-bottom: 1px solid #ffffff;
}

.ace-cloud_editor .ace_gutter-active-line {
    background-repeat: no-repeat;
    box-sizing: border-box;
    border-top: 1px solid #9191ac;
    border-bottom: 1px solid #9191ac;
}

.ace-cloud_editor .ace_marker-layer .ace_selected-word {
    border: 1px solid #bfceff;
}

.ace-cloud_editor .ace_fold {
    background-color: #2963d6;
    border-color: #3a3a42;
}

.ace-cloud_editor .ace_keyword {
    color: #9749d1;
}

.ace-cloud_editor .ace_meta.ace_tag {
    color: #2963d6;
}

.ace-cloud_editor .ace_constant {
    color: #a26202;
}

.ace-cloud_editor .ace_constant.ace_numeric {
    color: #a26202;
}

.ace-cloud_editor .ace_constant.ace_character.ace_escape {
    color: #d91792;
}

.ace-cloud_editor .ace_support.ace_function {
    color: #d1000a;
}

.ace-cloud_editor .ace_support.ace_class {
    color: #a26202;
}

.ace-cloud_editor .ace_storage {
    color: #9749d1;
}

.ace-cloud_editor .ace_invalid.ace_illegal {
    color: #ffffff;
    background-color: #2963d6;
}

.ace-cloud_editor .ace_invalid.ace_deprecated {
    color: #ffffff;
    background-color: #a26202;
}

.ace-cloud_editor .ace_string {
    color: #218000;
}

.ace-cloud_editor .ace_string.ace_regexp {
    color: #218000;
}

.ace-cloud_editor .ace_comment,
.ace-cloud_editor .ace_ghost_text {
    color: #697077;
    opacity: 1;
}

.ace-cloud_editor .ace_variable {
    color: #2963d6;
}

.ace-cloud_editor .ace_meta.ace_selector {
    color: #9749d1;
}

.ace-cloud_editor .ace_entity.ace_other.ace_attribute-name {
    color: #a26202;
}

.ace-cloud_editor .ace_entity.ace_name.ace_function {
    color: #d1000a;
}

.ace-cloud_editor .ace_entity.ace_name.ace_tag {
    color: #2963d6;
}

.ace-cloud_editor .ace_heading {
    color: #d1000a;
}

.ace-cloud_editor .ace_xml-pe {
    color: #a26202;
}
.ace-cloud_editor .ace_doctype {
    color: #2963d6;
}

.ace-cloud_editor .ace_tooltip {
    background-color: #ffffff;
    color: #3a3a42;
}

.ace-cloud_editor .ace_icon_svg.ace_error,
.ace-cloud_editor .ace_icon_svg.ace_error_fold {
    background-color: #d13212;
}
.ace-cloud_editor .ace_icon_svg.ace_warning,
.ace-cloud_editor .ace_icon_svg.ace_warning_fold {
    background-color: #906806;
}
.ace-cloud_editor .ace_icon_svg.ace_info {
    background-color: #0073bb;
}
.ace-cloud_editor .ace_highlight-marker {
    background: none;
    border: #2963d6 1px solid;
}
.ace-cloud_editor .ace_tooltip.ace_hover-tooltip:focus > div {
    outline: 1px solid #0073bb;
}
.ace-cloud_editor .ace_snippet-marker {
    background-color: #CED6E0;
    border: 0;
}

.ace-cloud_editor.ace_editor.ace_autocomplete .ace_marker-layer .ace_active-line {
    background-color: #f2f3f3;
    border: #0F68AE 1.5px solid;
}
.ace-cloud_editor.ace_editor.ace_autocomplete .ace_line-hover {
    border: 1px solid #16191f;
    background: #f2f3f3;
}
.ace-cloud_editor.ace_editor.ace_autocomplete .ace_completion-meta {
    color: #545b64;
    opacity: 1;
}
.ace-cloud_editor.ace_editor.ace_autocomplete .ace_completion-highlight{
    color: #0F68AE;
}
.ace-cloud_editor.ace_editor.ace_autocomplete {
    box-shadow: 0 1px 1px 0 #001c244d, 1px 1px 1px 0 #001c2426, -1px 1px 1px 0 #001c2426;
    line-height: 1.5;
    border: 1px solid #eaeded;
    background: #ffffff;
    color: #16191f;
}

`;

==> node-ace-code_1.40.1+~cs1.7.37.orig.tar.xz: ace-1.40.1/src/theme/cloud_editor-css.js <==
module.exports = `
.ace-cloud_editor .ace_gutter {
    background: #ffffff;
    color: #3a3a42;
}

.ace-cloud_editor .ace_tooltip-marker-error.ace_tooltip-marker {
    background-color: #d13212;
}
.ace-cloud_editor .ace_tooltip-marker-security.ace_tooltip-marker {
    background-color: #d13212;
}
.ace-cloud_editor .ace_tooltip-marker-warning.ace_tooltip-marker {
    background-color: #906806;
}

.ace-cloud_editor .ace_print-margin {
    width: 1px;
    background: #697077;
}

.ace-cloud_editor {
    background-color: #ffffff;
    color: #3a3a42;
}

.ace-cloud_editor .ace_cursor {
    color: #3a3a42;
}

.ace-cloud_editor .ace_marker-layer .ace_selection {
    background: #bfceff;
}

.ace-cloud_editor.ace_multiselect .ace_selection.ace_start {
    box-shadow: 0 0 3px 0px #ffffff;
    border-radius: 2px;
}

.ace-cloud_editor .ace_marker-layer .ace_step {
    background: #697077;
}

.ace-cloud_editor .ace_marker-layer .ace_bracket {
    margin: 0 0 0 -1px;
    border: 1px solid #697077;
}

.ace-cloud_editor .ace_marker-layer .ace_active-line {
    box-sizing: border-box;
    border-top: 1px solid #9191ac;
    border-bottom: 1px solid #9191ac;
}

.ace-cloud_editor .ace_gutter-cell_svg-icons {
    box-sizing: border-box;
    border-top: 1px solid #ffffff;
    border-bottom: 1px solid #ffffff;
}

.ace-cloud_editor .ace_gutter-active-line {
    background-repeat: no-repeat;
    box-sizing: border-box;
    border-top: 1px solid #9191ac;
    border-bottom: 1px solid #9191ac;
}

.ace-cloud_editor .ace_marker-layer .ace_selected-word {
    border: 1px solid #bfceff;
}

.ace-cloud_editor .ace_fold {
    background-color: #0E45B4;
    border-color: #3a3a42;
}

.ace-cloud_editor .ace_keyword {
    color: #9749d1;
}

.ace-cloud_editor .ace_meta.ace_tag {
    color: #0E45B4;
}

.ace-cloud_editor .ace_constant {
    color: #A16101;
}

.ace-cloud_editor .ace_constant.ace_numeric {
    color: #A16101;
}

.ace-cloud_editor .ace_constant.ace_character.ace_escape {
    color: #BD1880;
}

.ace-cloud_editor .ace_support.ace_function {
    color: #A81700;
}

.ace-cloud_editor .ace_support.ace_class {
    color: #A16101;
}

.ace-cloud_editor .ace_storage {
    color: #9749d1;
}

.ace-cloud_editor .ace_invalid.ace_illegal {
    color: #ffffff;
    background-color: #0E45B4;
}

.ace-cloud_editor .ace_invalid.ace_deprecated {
    color: #ffffff;
    background-color: #A16101;
}

.ace-cloud_editor .ace_string {
    color: #207A7F;
}

.ace-cloud_editor .ace_string.ace_regexp {
    color: #207A7F;
}

.ace-cloud_editor .ace_comment,
.ace-cloud_editor .ace_ghost_text {
    color: #697077;
    opacity: 1;
}

.ace-cloud_editor .ace_variable {
    color: #0E45B4;
}

.ace-cloud_editor .ace_meta.ace_selector {
    color: #9749d1;
}

.ace-cloud_editor .ace_entity.ace_other.ace_attribute-name {
    color: #A16101;
}

.ace-cloud_editor .ace_entity.ace_name.ace_function {
    color: #A81700;
}

.ace-cloud_editor .ace_entity.ace_name.ace_tag {
    color: #0E45B4;
}

.ace-cloud_editor .ace_heading {
    color: #A81700;
}

.ace-cloud_editor .ace_xml-pe {
    color: #A16101;
}
.ace-cloud_editor .ace_doctype {
    color: #0E45B4;
}

.ace-cloud_editor .ace_tooltip {
    background-color: #ffffff;
    color: #3a3a42;
}

.ace-cloud_editor .ace_icon_svg.ace_error,
.ace-cloud_editor .ace_icon_svg.ace_error_fold {
    background-color: #d13212;
}
.ace-cloud_editor .ace_icon_svg.ace_security,
.ace-cloud_editor .ace_icon_svg.ace_security_fold {
    background-color: #d13212;
}
.ace-cloud_editor .ace_icon_svg.ace_warning,
.ace-cloud_editor .ace_icon_svg.ace_warning_fold {
    background-color: #906806;
}
.ace-cloud_editor .ace_icon_svg.ace_info {
    background-color: #0073bb;
}
.ace-cloud_editor .ace_icon_svg.ace_hint {
    background-color: #0073bb;
}
.ace-cloud_editor .ace_highlight-marker {
    background: none;
    border: #0E45B4 1px solid;
}
.ace-cloud_editor .ace_tooltip.ace_hover-tooltip:focus > div {
    outline: 1px solid #0073bb;
}
.ace-cloud_editor .ace_snippet-marker {
    background-color: #CED6E0;
    border: 0;
}

.ace-cloud_editor.ace_editor.ace_autocomplete .ace_marker-layer .ace_active-line {
    background-color: #f2f3f3;
    border: #0F68AE 1.5px solid;
}
.ace-cloud_editor.ace_editor.ace_autocomplete .ace_line-hover {
    border: 1px solid #16191f;
    background: #f2f3f3;
}
.ace-cloud_editor.ace_editor.ace_autocomplete .ace_completion-meta {
    color: #545b64;
    opacity: 1;
}
.ace-cloud_editor.ace_editor.ace_autocomplete .ace_completion-highlight{
    color: #0F68AE;
}
.ace-cloud_editor.ace_editor.ace_autocomplete {
    box-shadow: 0 1px 1px 0 #001c244d, 1px 1px 1px 0 #001c2426, -1px 1px 1px 0 #001c2426;
    line-height: 1.5;
    border: 1px solid #eaeded;
    background: #ffffff;
    color: #16191f;
}

`;
